from adapay.request_tools import request_post, account_pay, page_base_url


class Account(object):

    @classmethod
    def payment(cls, **kwargs):
        """
        创建钱包支付对象
        """
        return request_post(account_pay, kwargs, base_url=page_base_url)



from adapay_core import log_util

from adapay.payment import *
from adapay.payment_reverse import *
from adapay.payment_confrim import *

from adapay.refund import *

from adapay.member import *
from adapay.corp_member import *

from adapay.settle_account import *

from adapay.checkout import *
from adapay.account import *
from adapay.drawcash import *
from adapay.wallet import *
from adapay.transfer import *
from adapay.fast_pay import *
from adapay.un_freeze_account import *
from adapay.freeze_account import *

from adapay.adapay_tools import *

mer_config = {}

"""
全局的配置字典
{"member_id1":{},
 "member_id2":{},
 "member_id3":{},
   ···
}
"""

from fishbase.fish_logger import set_log_file, set_log_stdout

connect_timeout = 30


def init_log(console_enable=False, log_level='', log_tag='{adapay}', log_file_path=''):
    """
    :param log_tag:
    :param log_level:
    :param console_enable: 是否在控台输出日志
    :param log_file_path:
    :return:
    """
    if console_enable:
        set_log_stdout()
    if log_file_path:
        set_log_file(log_file_path)
    if log_level:
        log_util.log_level = log_level
        if log_tag:
            log_util.log_tag = log_tag


# sdk 版本
__version__ = '1.3.2'




from adapay.request_tools import payment_create, payment_query, payment_list, payment_close, request_post, request_get


class AdapayCommon(object):

    @classmethod
    def requestAdapay(cls, **kwargs):
        """
        创建订单
        """
        if not kwargs.get('currency'):
            kwargs['currency'] = 'cny'

        return request_post(payment_create, kwargs)

    @classmethod
    def queryAdapay(cls, **kwargs):
        """
        支付查询
        """
        url = payment_query.format(payment_id=kwargs.get('payment_id'))
        return request_get(url, kwargs)

    @classmethod
    def requestAdapayUits(cls, **kwargs):
        """
        支付查询
        """
        return request_get(payment_list, kwargs)

    @classmethod
    def queryAdapayUits(cls, **kwargs):
        """
        关单请求
        """
        url = payment_close.format(kwargs['payment_id'])
        return request_post(url, kwargs)



from adapay.request_tools import request_post, request_get, cash_draw_create, cash_draw_status


class Drawcash(object):

    @classmethod
    def create(cls, **kwargs):
        """
        取现
        """
        return request_post(cash_draw_create, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        取现状态查询
        """
        return request_get(cash_draw_status, kwargs)



"""

结算账户对象
"""

from adapay.request_tools import request_get, request_post, settle_account_create, settle_account_query, \
    settle_account_delete, settle_account_balance_query, settle_account_detail_query, settle_account_modify, \
    settle_account_commissions_list, settle_account_commissions_create


class SettleAccount:

    @classmethod
    def create_settle(cls, **kwargs):
        """
        创建结算账户
        """
        return request_post(settle_account_create, kwargs)

    @classmethod
    def query_settle(cls, **kwargs):
        """
        查询结算账户
        """
        url = settle_account_query.format(settle_account_id=kwargs.get('settle_account_id'))
        return request_get(url, kwargs)

    @classmethod
    def modify_settle(cls, **kwargs):
        """
        修改结算配置
        """
        return request_post(settle_account_modify, kwargs)

    @classmethod
    def delete_settle(cls, **kwargs):
        """
        删除结算账户
        """
        return request_post(settle_account_delete, kwargs)

    @classmethod
    def query_settle_details(cls, **kwargs):
        """
        查询结算账户明细
        """
        return request_get(settle_account_detail_query, kwargs)

    @classmethod
    def query_balance(cls, **kwargs):
        """
        查询账户余额
        """
        return request_get(settle_account_balance_query, kwargs)

    @classmethod
    def create_commissions_settle(cls, **kwargs):
        """
        创建服务商分账
        """
        return request_post(settle_account_commissions_create, kwargs)

    @classmethod
    def list_commissions_settle(cls, **kwargs):
        """
        列表服务商分账
        """
        return request_get(settle_account_commissions_list, kwargs)



from adapay.request_tools import request_post, request_get, un_freeze_account_create, un_freeze_account_query_list


class UnFreezeAccount(object):

    @classmethod
    def create(cls, **kwargs):
        """
        创建账户解冻对象
        """
        return request_post(un_freeze_account_create, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
        查询账户解冻列表
        """
        return request_get(un_freeze_account_query_list, kwargs)



# url path 统一管理 花括号中变量代表待替换值

from adapay_core import ApiRequest
import adapay
pay_message_token = '/v1/token/apply'

# ----------payment 对象----------
payment_create = '/v1/payments'
payment_query = '/v1/payments/{payment_id}'
payment_close = '/v1/payments/{}/close'
payment_list = '/v1/payments/list'

# ----------confirm 对象----------
confirm_create = '/v1/payments/confirm'
confirm_query = '/v1/payments/confirm/{payment_confirm_id}'
confirm_query_list = '/v1/payments/confirm/list'

# ----------reverse 对象----------
reverse_create = '/v1/payments/reverse'
reverse_query = '/v1/payments/reverse/{reverse_id}'
reverse_query_list = '/v1/payments/reverse/list'

# ----------refund 对象----------
refund_create = '/v1/payments/{id}/refunds'
refund_query = '/v1/payments/refunds'

# ----------member 对象 ----------
member_create = '/v1/members'
member_query = '/v1/members/{member_id}'
member_query_list = '/v1/members/list'
member_update = '/v1/members/update'

# ----------corp_member 对象----------
corp_member_create = '/v1/corp_members'
corp_member_query = '/v1/corp_members/{member_id}'

# ----------settle_account 对象 ----------
settle_account_create = '/v1/settle_accounts'
settle_account_modify = '/v1/settle_accounts/modify'
settle_account_query = '/v1/settle_accounts/{settle_account_id}'
settle_account_delete = '/v1/settle_accounts/delete'
settle_account_detail_query = '/v1/settle_accounts/settle_details'
settle_account_balance_query = '/v1/settle_accounts/balance'

# 查询服务商分账对象列表
settle_account_commissions_list = '/v1/settle_accounts/commissions/list'

# 创建服务商分账对象
settle_account_commissions_create = '/v1/settle_accounts/commissions'

transfer_create = '/v1/settle_accounts/transfer'
list_transfer = '/v1/settle_accounts/transfer/list'

# ----------Drawcash 对象 ----------
cash_draw_create = '/v1/cashs'
cash_draw_status = '/v1/cashs/stat'

# ----------云闪付用户id ----------
query_identity = '/v1/union/user_identity'

# ----------bill 账单----------
bill_download = '/v1/bill/download'

# ----------wallet 对象 ----------
wallet_login = '/v1/walletLogin'

# ----------Account 对象 ----------
account_pay = '/v1/account/payment'

# ----------checkout 对象 ----------
checkout_create = '/v1/checkout'
checkout_list = '/v1/checkout/list'

freeze_account_create = '/v1/settle_accounts/freeze'
freeze_account_query_list = '/v1/settle_accounts/freeze/list'

un_freeze_account_create = '/v1/settle_accounts/unfreeze'
un_freeze_account_query_list = '/v1/settle_accounts/unfreeze/list'

# ----------快捷绑卡 对象 ----------
fast_pay_card_bind = '/v1/fast_card/apply'
fast_pay_card_bind_confirm = '/v1/fast_card/confirm'
fast_pay_card_bind_list = '/v1/fast_card/list'

# ----------快捷支付确认 ----------
fast_pay_confirm = '/v1/fast_pay/confirm'
fast_pay_sms_code = '/v1/fast_pay/sms_code'


# ----------支付系统 ----------
pay_base_url = 'https://api.adapay.tech'

# ----------钱包系统 ----------
page_base_url = 'https://page.adapay.tech'

# ----------Adapay 公钥 ----------
public_key = 'MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCwN6xgd6Ad8v2hIIsQVnbt8a3JituR8o4Tc3B5WlcFR55bz4OMqrG/356Ur3cPb' \
             'c2Fe8ArNd/0gZbC9q56Eb16JTkVNA/fye4SXznWxdyBPR7+guuJZHc/VW2fKH2lfZ2P3Tt0QkKZZoawYOGSMdIvO+WqK44updya' \
             'x0ikK6JlNQIDAQAB'


# 这里外部传入url，目前存在多个base_url
def __request_init(url, request_params, base_url):
    mer_key = request_params.pop('mer_key', None)
    config_info = adapay.mer_config[mer_key]
    ApiRequest.base_url = base_url if base_url else pay_base_url
    ApiRequest.build(config_info["api_key"], config_info['private_key'], public_key, url,
                     request_params, adapay.__version__, adapay.connect_timeout)


def request_post(url, request_params, files=None, base_url=''):
    __request_init(url, request_params, base_url)
    return ApiRequest.post(files)


def request_get(url, request_params, base_url=''):
    __request_init(url, request_params, base_url)
    return ApiRequest.get()



from adapay.request_tools import request_post, request_get, checkout_create, checkout_list, page_base_url


class Checkout(object):

    @classmethod
    def checkout(cls, **kwargs):
        """
        创建收银台对象
        :param kwargs:
        :return:
        """
        return request_post(checkout_create, kwargs, base_url=page_base_url)

    @classmethod
    def list(cls, **kwargs):
        """
        创建收银台对象
        :param kwargs:
        :return:
        """
        return request_get(checkout_list, kwargs, base_url=page_base_url)



import os

from adapay.request_tools import request_post, request_get, corp_member_create, corp_member_query


class CorpMember(object):

    @classmethod
    def create(cls, **kwargs):
        """
        创建企业用户
        """
        file_path = kwargs.get('attach_file')
        files = {'attach_file': (os.path.basename(file_path), open(file_path, 'rb'), 'application/octet-stream')}
        kwargs.pop('attach_file')
        return request_post(corp_member_create, kwargs, files)

    @classmethod
    def query(cls, **kwargs):
        """
        查询企业用户
        """
        url = corp_member_query.format(member_id=kwargs.get('member_id'))
        return request_get(url, kwargs)



from adapay.request_tools import reverse_create, reverse_query, reverse_query_list, request_post, request_get


class PaymentReverse(object):

    @classmethod
    def create(cls, **kwargs):
        """
        支付撤销
        """
        return request_post(reverse_create, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        查询支付撤销
        """
        url = reverse_query.format(reverse_id=kwargs.get('reverse_id'))
        return request_get(url, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
        查询支付撤销列表
        """
        return request_get(reverse_query_list, kwargs)



from adapay.request_tools import request_post, request_get, member_create, member_query, \
    member_query_list, member_update


class Member(object):

    @classmethod
    def create(cls, **kwargs):
        """
        创建用户
        """
        return request_post(member_create, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        查询用户
        """
        url = member_query.format(member_id=kwargs.get('member_id'))
        return request_get(url, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
        查询用户列表
        """
        return request_get(member_query_list, kwargs)

    @classmethod
    def update(cls, **kwargs):
        """
        更新用户
        """
        return request_post(member_update, kwargs)



from adapay.request_tools import request_post, bill_download, query_identity, public_key
from adapay_core.rsa_utils import rsa_design


class AdapayTools(object):

    @classmethod
    def union_user_id(cls, **kwargs):
        return request_post(query_identity, kwargs)

    @classmethod
    def download_bill(cls, **kwargs):
        return request_post(bill_download, kwargs)

    @classmethod
    def verify_sign(cls, data, sign, pub_key=public_key):
        return rsa_design(sign, data, pub_key)



from adapay.request_tools import request_post, request_get, freeze_account_create, freeze_account_query_list


class FreezeAccount(object):

    @classmethod
    def create(cls, **kwargs):
        """
        创建账户冻结对象
        """
        return request_post(freeze_account_create, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
        查询账户冻结列表
        """
        return request_get(freeze_account_query_list, kwargs)



"""

退款接口
"""

from adapay.request_tools import refund_create, refund_query, request_post, request_get


class Refund(object):

    @classmethod
    def create(cls, **kwargs):
        """
        发起退款流程
        """

        url = refund_create.format(kwargs.get('id', ''))
        return request_post(url, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        退款流程查询
        """

        return request_get(refund_query, kwargs)



from setuptools import setup
import io
import re

with io.open('README.rst', 'rt', encoding='utf8') as f:
    readme = f.read()

with io.open('adapay/__init__.py', 'rt', encoding='utf8') as f:
    version = re.search(r'__version__ = \'(.*?)\'', f.read()).group(1)

setup(
    name='adapay',
    version=version,
    author="adapay developers",
    author_email="hi@adapay.tech",
    install_requires=['adapay-core>=1.2.0'],
    url='https://docs.adapay.tech/sdk/pythonsdkaccess.html',
    description='adapay,an adapter of various pay channels to python server client',
    long_description=readme,
    packages=['adapay'],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ]

)



from adapay.request_tools import request_post, request_get, fast_pay_card_bind, fast_pay_card_bind_confirm, \
    fast_pay_card_bind_list, fast_pay_confirm, fast_pay_sms_code, page_base_url


class FastPay(object):

    @classmethod
    def card_bind(cls, **kwargs):
        """
        创建快捷支付绑卡对象
        """
        return request_post(fast_pay_card_bind, kwargs, base_url=page_base_url)

    @classmethod
    def card_bind_list(cls, **kwargs):
        """
        查询快捷支付列表
        """
        return request_get(fast_pay_card_bind_list, kwargs, base_url=page_base_url)

    @classmethod
    def card_bind_confirm(cls, **kwargs):
        """
        快捷支付绑卡确认
        """
        return request_post(fast_pay_card_bind_confirm, kwargs, base_url=page_base_url)

    @classmethod
    def confirm(cls, **kwargs):
        """
        快捷支付确认
        """
        return request_post(fast_pay_confirm, kwargs)

    @classmethod
    def sms_code(cls, **kwargs):
        """
        快捷支付短信重发
        """
        return request_post(fast_pay_sms_code, kwargs)



from adapay.request_tools import request_post, wallet_login, page_base_url


class Wallet(object):

    @classmethod
    def login(cls, **kwargs):
        """
        钱包用户登录
        :param kwargs:
        :return:
        """
        return request_post(wallet_login, kwargs, base_url=page_base_url)



from adapay.request_tools import request_get, request_post, confirm_create, confirm_query, confirm_query_list


class PaymentConfrim:

    @classmethod
    def create(cls, **kwargs):
        """
        创建订单确认
        """
        return request_post(confirm_create, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        查询订单确认
        """
        url = confirm_query.format(payment_confirm_id=kwargs.get('payment_confirm_id'))
        return request_get(url, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
         查询订单确认列表
        """
        return request_get(confirm_query_list, kwargs)



"""

转账对象
"""

from adapay.request_tools import request_get, request_post, transfer_create, list_transfer


class Transfer:

    @classmethod
    def create(cls, **kwargs):
        """
        账户转账
        """
        return request_post(transfer_create, kwargs)

    @classmethod
    def list(cls, **kwargs):
        """
        账户转账列表查询
        """
        return request_get(list_transfer, kwargs)
